@@ -143,8 +143,8 @@ class MainInterface:
         video.grid(sticky=N, pady = 10)
         video_key = Label(video_player, text='\n\n  Keyboard shortcuts for video navigation: \n p = Pause/Play'
                                              '\n\n After pressing pause:'
-                                             '\n o = +2 frames \n e = +10 frames \n w = +1 second'
-                                             '\n\n t = -2 frames \n s = -10 frames \n x = -1 second'
+                                             '\n r = +2 frames \n e = +10 frames \n w = +1 second'
+                                             '\n\n o = -2 frames \n i = -10 frames \n u = -1 second'
                                              '\n\n q = Close video window \n\n')
         video_key.grid(sticky=W)
         update = Button(video_player, text='Show current video frame',
@@ -178,7 +178,6 @@ class MainInterface:
         if self.rangeOn.get():
             s = int(self.firstFrame.get())
             e = int(self.lastFrame.get())
-            print(s, e)
             save_values(s, e)
             if e < len(frames_in) - 1:
                 load_frame(e + 1, master, self.fbox)
@@ -395,14 +394,22 @@ def set_values(dictionary):
 
 # Saves the values of each behavior in the DataFrame and prints out the updated data frame
 def save_values(start, end):
+    global columns
+    contprintLoop = True
+    print('\n')
     if start == end:
         for i in range(len(behaviors)):
             df.at[current_frame_number, columns[i]] = int(behaviors[i])
+            if behaviors[i] != 0:
+                print('Annotated behavior: ' + columns[i] + '. Frame: ' + str(start) + '.')
+
     if start != end:
         for i in range(start, end+1):
             for b in range(len(behaviors)):
                 df.at[i, columns[b]] = int(behaviors[b])
-    print(df.ix[current_frame_number])
+                if behaviors[b] != 0 and (contprintLoop == True):
+                    print('Annotated behavior: ' + columns[b] + '. Start frame: ' + str(start) + '. End frame: ' + str(end))
+            contprintLoop = False
 
 
 # Appends data to corresponding features_extracted csv and exports as new csv
